@@ -7,12 +7,14 @@ from contextlib import contextmanager
 from os.path import join
 from subprocess import Popen
 from pathlib import Path
+from warnings import warn
 
 try:
     from subprocess import CREATE_NEW_PROCESS_GROUP
+
     WINDOWS = True
 except ImportError:
-    WINDOWS = False 
+    WINDOWS = False
 
 from PyQt5 import QtGui
 import pyqtgraph as pg
@@ -21,7 +23,8 @@ from .qdarkstyle import load_stylesheet_pyqt5
 from .gui import Iris, image_folder
 from ..raw import open_raw
 
-DETACHED_PROCESS = 0x00000008          # 0x8 | 0x200 == 0x208
+DETACHED_PROCESS = 0x00000008  # 0x8 | 0x200 == 0x208
+
 
 @contextmanager
 def gui_environment():
@@ -34,17 +37,20 @@ def gui_environment():
     Note that interactions with the screen (e.g. mask creation) assumes that the image-axis order is 
     row-major. 
     """
-    old_qt_lib = os.environ.get('PYQTGRAPH_QT_LIB', 'PyQt5')    # environment variable might not exist
-    os.environ['PYQTGRAPH_QT_LIB'] = 'PyQt5'
+    old_qt_lib = os.environ.get(
+        "PYQTGRAPH_QT_LIB", "PyQt5"
+    )  # environment variable might not exist
+    os.environ["PYQTGRAPH_QT_LIB"] = "PyQt5"
 
-    old_image_axis_order = pg.getConfigOption('imageAxisOrder')
-    pg.setConfigOptions(imageAxisOrder = 'row-major')
+    old_image_axis_order = pg.getConfigOption("imageAxisOrder")
+    pg.setConfigOptions(imageAxisOrder="row-major")
 
     yield
-    os.environ['PYQTGRAPH_QT_LIB'] = old_qt_lib
-    pg.setConfigOptions(imageAxisOrder = old_image_axis_order)
+    os.environ["PYQTGRAPH_QT_LIB"] = old_qt_lib
+    pg.setConfigOptions(imageAxisOrder=old_image_axis_order)
 
-def run(path = None, **kwargs):
+
+def run(path=None, dset_type=None, **kwargs):
     """ 
     Run the iris GUI with the correct environment, and open a dataset. Invalid
     datasets are ignored.
@@ -54,21 +60,20 @@ def run(path = None, **kwargs):
     path : path-like or None, optional
         Path to either a raw dataset or a processed datasets. 
         Raw dataset formats will be guessed.
+    dset_type : {'raw', 'reduced', None}, optional
+        Dataset type.
     """
 
     with gui_environment():
         app = QtGui.QApplication(sys.argv)
         app.setStyleSheet(load_stylesheet_pyqt5())
-        app.setWindowIcon(QtGui.QIcon(join(image_folder, 'eye.png')))
+        app.setWindowIcon(QtGui.QIcon(join(image_folder, "eye.png")))
         gui = Iris()
 
-        # If a path is provided, we try to load
         if path:
             path = Path(path)
-            if path.suffix in {'.h5', '.hdf5'}:
-                gui.dataset_path_signal.emit(str(path)) # signal has signature [str]
-            else:
-                # For raw datasets, we need to guess the AbstractRawDataset subclass
+            if dset_type == "raw":
+                # Determine the class
                 try:
                     with open_raw(path) as dset:
                         dataformat = dset.__class__
@@ -78,12 +83,17 @@ def run(path = None, **kwargs):
                     # No errors, valid dataset
                     # note : signal has signature [str, object]
                     gui.raw_dataset_path_signal.emit(str(path), dataformat)
+            if dset_type == "reduced":
+                gui.dataset_path_signal.emit(str(path))  # signal has signature [str]
+            else:
+                warn(f"dset_type invalid value: {dset_type}. Ignoring path.")
 
         # Possibility to restart. A complete new interpreter must
         # be used so that new plug-ins are loaded correctly.
         gui.restart_signal.connect(lambda: restart(app))
         return app.exec_()
 
+
 def restart(application):
     """ Restart an application in a separate process. A new python interpreter is used, which
     means that plug-ins are reloaded. """
@@ -91,4 +101,4 @@ def restart(application):
     flags = DETACHED_PROCESS
     if WINDOWS:
         flags = flags | CREATE_NEW_PROCESS_GROUP
-    return Popen(['pythonw', '-m', 'iris'], creationflags = flags)
+    return Popen(["pythonw", "-m", "iris"], creationflags=flags)
